package smash.appointment.parse;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.Row;

public class PrcControlParser extends SubjectParser {

	@Override
	protected String parseScreeningNumber(Row row) {
		String number = getString(row.getCell(16));
		if (number.trim().isEmpty()) {
			return "";
		} else {
			return "P-" + number;
		}
	}

	@Override
	protected String parseName(Row row) {
		return getString(row.getCell(1));
	}

	@Override
	protected String parseSurname(Row row) {
		return getString(row.getCell(0));
	}

	@Override
	protected String parseNdNumber(Row row) {
		return getString(row.getCell(14));
	}

	@Override
	protected String getSheetName() {
		return "Contrôles";
	}

	@Override
	protected int getInitRow() {
		return 1;
	}

	@Override
	protected String parseBirthDate(Row row) {
		return "";
	}

	@Override
	protected String parsemPowerId(Row row) {
		return "";
	}

	@Override
	protected String parseAddDate(Row row) {
		return getDate(row.getCell(8), Calendar.getInstance());
	}

	@Override
	protected String parseReferal(Row row) {
		return "";
	}

	@Override
	protected String parseDiagnosisYear(Row row) {
		return "";
	}

	@Override
	protected String parseMail(Row row) {
		return getString(row.getCell(5));
	}

	@Override
	protected String parsePhone3(Row row) {
		String phones[] = getPhones(row);
		if (phones.length > 2) {
			return phones[2].trim();
		}
		return "";
	}

	private String[] getPhones(Row row) {
		return getString(row.getCell(4)).split("/");
	}

	@Override
	protected String parsePhone2(Row row) {
		String phones[] = getPhones(row);
		if (phones.length > 1) {
			return phones[1].trim();
		}
		return "";
	}

	@Override
	protected String parsePhone1(Row row) {
		String phones[] = getPhones(row);
		return phones[0].trim();
	}

	@Override
	protected String parseCity(Row row) {
		String string = getString(row.getCell(3));
		int spaceIndex = string.indexOf(" ");
		if (spaceIndex > 0) {
			return string.substring(spaceIndex).trim();
		}
		return string;
	}

	@Override
	protected String parseCountry(Row row) {
		return "";
	}

	@Override
	protected String parseZipCode(Row row) {
		String string = getString(row.getCell(3));
		int spaceIndex = string.indexOf(" ");
		if (spaceIndex > 0) {
			return string.substring(0,spaceIndex);
		}
		return "";
	}

	@Override
	protected String parseAddress(Row row) {
		return getString(row.getCell(2));
	}

	@Override
	protected String parseRemarks(Row row) {
		String remark1 = getString(row.getCell(9));
		String remark2 = "";

		String result = "";
		if (!remark1.trim().isEmpty()) {
			result = result + remark1 + "\n";
		}
		if (!remark2.trim().isEmpty()) {
			result = result + remark2 + "\n";
		}
		return result;
	}

	@Override
	protected String parseDiagnosis(Row row) {
		return "";
	}

	@Override
	protected SubjectType parseType(Row row) {
		return SubjectType.CONTROL;
	}

	@Override
	protected List<String> parseLanguages(Row row) {
		return new ArrayList<>();
	}

	@Override
	protected String parseToBeSeenAt(Row row) {
		return "P";
	}
	@Override
	protected boolean parseDead(Row row) {
		return false;
	}

	@Override
	protected boolean parseResigned(Row row) {
		return false;
	}

}
